@@ -27,7 +27,7 @@ cb_help_response (GtkWidget *dialog, gint response, gpointer unused)
   if (response == GTK_RESPONSE_HELP)
     {
       g_signal_stop_emission_by_name (dialog, "response");
-      screenshooter_open_help ();
+      screenshooter_open_help (GTK_WINDOW (dialog));
     }
 }
 
@@ -124,6 +124,10 @@ gboolean screenshooter_action_idle (ScreenshotData *sd)
         {
           if (sd->action == OPEN)
             screenshooter_open_screenshot (screenshot_path, sd->app);
+          else if (sd->action == UPLOAD_IMGUR) {
+              screenshooter_upload_to_imgur   (screenshot_path,
+                                               sd->title);
+            }
           else
             {
               gchar *new_last_user = NULL;
