@@ -35,6 +35,7 @@ gboolean fullscreen = FALSE;
 gboolean mouse = FALSE;
 gboolean upload = FALSE;
 gboolean clipboard = FALSE;
+gboolean upload_imgur = FALSE;
 gchar *screenshot_dir;
 gchar *application;
 gint delay = 0;
@@ -86,6 +87,11 @@ static GOptionEntry entries[] =
     N_("Host the screenshot on ZimageZ, a free online image hosting service"),
     NULL
   },
+  {
+    "imgur", 'i', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &upload_imgur,
+    N_("Host the screenshot on Imgur, a free online image hosting service"),
+    NULL
+  },
   {
     "version", 'V', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &version,
     N_("Version information"),
@@ -111,7 +117,7 @@ cb_dialog_response (GtkWidget *dialog, gint response, ScreenshotData *sd)
   if (response == GTK_RESPONSE_HELP)
     {
       g_signal_stop_emission_by_name (dialog, "response");
-      screenshooter_open_help ();
+      screenshooter_open_help (GTK_WINDOW (dialog));
     }
   else if (response == GTK_RESPONSE_OK)
     {
@@ -230,6 +236,21 @@ int main (int argc, char **argv)
       g_free (sd);
       return EXIT_FAILURE;
     }
+  else if (upload_imgur && upload)
+    {
+      g_printerr (conflict_error, "upload", "imgur");
+      return EXIT_FAILURE;
+    }
+  else if (upload_imgur && (screenshot_dir != NULL))
+    {
+      g_printerr (conflict_error, "imgur", "save");
+      return EXIT_FAILURE;
+    }
+  else if (upload_imgur && (application != NULL))
+    {
+      g_printerr (conflict_error, "imgur", "open");
+      return EXIT_FAILURE;
+    }
 
   /* Warn that action options, mouse and delay will be ignored in
    * non-cli mode */
@@ -237,6 +258,8 @@ int main (int argc, char **argv)
     g_printerr (ignore_error, "open");
   if ((screenshot_dir != NULL)  && !(fullscreen || window || region ))
     g_printerr (ignore_error, "save");
+  if (upload_imgur && !(fullscreen || window || region))
+    g_printerr (ignore_error, "imgur");
   if (upload && !(fullscreen || window || region))
     g_printerr (ignore_error, "upload");
   if (clipboard && !(fullscreen || window || region))
@@ -246,9 +269,6 @@ int main (int argc, char **argv)
   if (mouse && !(fullscreen || window || region))
     g_printerr (ignore_error, "mouse");
 
-  if (!g_thread_supported ())
-    g_thread_init (NULL);
-
   /* Just print the version if we are in version mode */
   if (version)
     {
@@ -311,6 +331,12 @@ int main (int argc, char **argv)
           sd->action = CLIPBOARD;
           sd->action_specified = TRUE;
         }
+      else if (upload_imgur)
+        {
+          sd->app = g_strdup ("none");
+          sd->action = UPLOAD_IMGUR;
+          sd->action_specified = TRUE;
+        }
       else
         {
           sd->app = g_strdup ("none");
@@ -344,7 +370,7 @@ int main (int argc, char **argv)
     {
       GtkWidget *dialog;
 
-      /* Use 0 as the minimal delay */
+      /* Use 1 as the minimal delay, 0 may show corrupted windows */
       if (sd->delay == 0)
         sd->delay = 1;
 
